==> Alpha-0.7.3-src.tar.bz2: Alpha-0.7.3-src/Alpha/alpha_mc.h <==
// alpha_mc.mc
// file ////////////////////////////////////////////////////////////////////
//
//  Values are 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev - is the severity code
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag
//
//      R - is a reserved bit
//
//      Facility - is the facility code
//
//      Code - is the facility's status code
//
//
// Define the facility codes
//


//
// Define the severity codes
//


//
// MessageId: MSG_FILE_FILEISDIRTY
//
// MessageText:
//
//  %1%nThis file has been modified. Do you save?
//
#define MSG_FILE_FILEISDIRTY             100L

//
// MessageId: MSG_FILE_ASKREOPEN
//
// MessageText:
//
//  Do you reopen current file?
//
#define MSG_FILE_ASKREOPEN               101L

//
// MessageId: MSG_FILE_ASKREOPENINDIRTY
//
// MessageText:
//
//  Current file has been modified. The change is lost, if reopen. Do you reoprn?
//
#define MSG_FILE_ASKREOPENINDIRTY        102L

//
// MessageId: MSG_FILE_FILEHASBEENMODIFIEDBYOTHER
//
// MessageText:
//
//  %1%nThis file has been modified by other process. Do you reopen?
//
#define MSG_FILE_FILEHASBEENMODIFIEDBYOTHER 103L

// search //////////////////////////////////////////////////////////////////
//
// MessageId: MSG_SEARCH_TEXTNOTFOUND
//
// MessageText:
//
//  Specified text is not found.
//
#define MSG_SEARCH_TEXTNOTFOUND          104L

//
// MessageId: MSG_SEARCH_REPLACESUCCEEDED
//
// MessageText:
//
//  Replaced %1 text(s).
//
#define MSG_SEARCH_REPLACESUCCEEDED      105L

// debug ///////////////////////////////////////////////////////////////////
//
// MessageId: MSG_DEBUG_FAILEDTOGETPDM
//
// MessageText:
//
//  Failed to get Process Debug Manager. Can not continue debug.
//
#define MSG_DEBUG_FAILEDTOGETPDM         106L

//
// MessageId: MSG_DEBUG_INVALIDLANGUAGENAME
//
// MessageText:
//
//  No language bounded to current file's extension name, or language name is incorrect. Can not continue debug.
//
#define MSG_DEBUG_INVALIDLANGUAGENAME    107L

//
// MessageId: MSG_DEBUG_ENGINENOTSUPPORTDEBUGGING
//
// MessageText:
//
//  This script engine does not support debugging. Do you continue?
//
#define MSG_DEBUG_ENGINENOTSUPPORTDEBUGGING 108L

//
// MessageId: MSG_DEBUG_ENGINENOTSUPPORTPARSING
//
// MessageText:
//
//  This script engine does not provide parser. Can not continue debug.
//
#define MSG_DEBUG_ENGINENOTSUPPORTPARSING 109L

//
// MessageId: MSG_DEBUG_DOCUMENTISDEBUGGING
//
// MessageText:
//
//  %1%nThis document is debugging now. Do you stop debugging?
//
#define MSG_DEBUG_DOCUMENTISDEBUGGING    110L

// tool ////////////////////////////////////////////////////////////////////
//
// MessageId: MSG_TOOL_EXENOTREGISTERED
//
// MessageText:
//
//  "%1"%nThis document type is not registered program.
//
#define MSG_TOOL_EXENOTREGISTERED        111L

//
// MessageId: MSG_TOOL_FAILEDTORUNEXE
//
// MessageText:
//
//  Failed to run registered program.%nProgram path name may be incorrect.
//
#define MSG_TOOL_FAILEDTORUNEXE          112L

// menu ////////////////////////////////////////////////////////////////////
//
// MessageId: MSG_MENU_FILETOP
//
// MessageText:
//
//  &File
//
#define MSG_MENU_FILETOP                 113L

//
// MessageId: MSG_MENU_FILEMRU
//
// MessageText:
//
//  &Most Recent Used Files
//
#define MSG_MENU_FILEMRU                 114L

//
// MessageId: MSG_MENU_FILEOPE
//
// MessageText:
//
//  &File Operation
//
#define MSG_MENU_FILEOPE                 115L

//
// MessageId: MSG_MENU_EDITTOP
//
// MessageText:
//
//  &Edit
//
#define MSG_MENU_EDITTOP                 116L

//
// MessageId: MSG_MENU_EDITADVANCED
//
// MessageText:
//
//  Ad&vanced Operation
//
#define MSG_MENU_EDITADVANCED            117L

//
// MessageId: MSG_MENU_EDITINSUNICTRL
//
// MessageText:
//
//  &Insert Unicode Controls
//
#define MSG_MENU_EDITINSUNICTRL          118L

//
// MessageId: MSG_MENU_EDITINSUNIWS
//
// MessageText:
//
//  Insert Unicode &Whitespace
//
#define MSG_MENU_EDITINSUNIWS            119L

//
// MessageId: MSG_MENU_EDITPLUGINS
//
// MessageText:
//
//  Plu&gins
//
#define MSG_MENU_EDITPLUGINS             120L

//
// MessageId: MSG_MENU_EDITFAILEDTOLOAD
//
// MessageText:
//
//  (Failed to load)
//
#define MSG_MENU_EDITFAILEDTOLOAD        121L

//
// MessageId: MSG_MENU_SEARCHTOP
//
// MessageText:
//
//  &Search
//
#define MSG_MENU_SEARCHTOP               122L

//
// MessageId: MSG_MENU_VIEWTOP
//
// MessageText:
//
//  &View
//
#define MSG_MENU_VIEWTOP                 123L

//
// MessageId: MSG_MENU_DEBUGTOP
//
// MessageText:
//
//  &Debug
//
#define MSG_MENU_DEBUGTOP                124L

//
// MessageId: MSG_MENU_TOOLTOP
//
// MessageText:
//
//  &Tool
//
#define MSG_MENU_TOOLTOP                 125L

//
// MessageId: MSG_MENU_TOOLAPPLYDOCTYPE
//
// MessageText:
//
//  &Apply Document Type
//
#define MSG_MENU_TOOLAPPLYDOCTYPE        126L

//
// MessageId: MSG_MENU_HELPTOP
//
// MessageText:
//
//  &Help
//
#define MSG_MENU_HELPTOP                 127L

==> Alpha-0.7.5-src.tar.bz2: Alpha-0.7.5-src/Alpha/alpha_mc.h <==
// alpha_mc.mc
// file ////////////////////////////////////////////////////////////////////
//
//  Values are 32 bit values layed out as follows:
//
//   3 3 2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
//   1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
//  +---+-+-+-----------------------+-------------------------------+
//  |Sev|C|R|     Facility          |               Code            |
//  +---+-+-+-----------------------+-------------------------------+
//
//  where
//
//      Sev - is the severity code
//
//          00 - Success
//          01 - Informational
//          10 - Warning
//          11 - Error
//
//      C - is the Customer code flag
//
//      R - is a reserved bit
//
//      Facility - is the facility code
//
//      Code - is the facility's status code
//
//
// Define the facility codes
//


//
// Define the severity codes
//


//
// MessageId: MSG_FILE_FILEISDIRTY
//
// MessageText:
//
//  %1%nThis file has been modified. Do you save?
//
#define MSG_FILE_FILEISDIRTY             100L

//
// MessageId: MSG_FILE_ASKREOPEN
//
// MessageText:
//
//  Do you reopen current file?
//
#define MSG_FILE_ASKREOPEN               101L

//
// MessageId: MSG_FILE_ASKREOPENINDIRTY
//
// MessageText:
//
//  Current file has been modified. The change is lost, if reopen. Do you reoprn?
//
#define MSG_FILE_ASKREOPENINDIRTY        102L

//
// MessageId: MSG_FILE_FILEHASBEENMODIFIEDBYOTHER
//
// MessageText:
//
//  %1%nThis file has been modified by other process. Do you reopen?
//
#define MSG_FILE_FILEHASBEENMODIFIEDBYOTHER 103L

// search //////////////////////////////////////////////////////////////////
//
// MessageId: MSG_SEARCH_TEXTNOTFOUND
//
// MessageText:
//
//  Specified text is not found.
//
#define MSG_SEARCH_TEXTNOTFOUND          104L

//
// MessageId: MSG_SEARCH_REPLACESUCCEEDED
//
// MessageText:
//
//  Replaced %1 text(s).
//
#define MSG_SEARCH_REPLACESUCCEEDED      105L

//
// MessageId: MSG_SEARCH_FAILEDTOLOADREGEXPENGINE
//
// MessageText:
//
//  Failed to load regular expression engine.%nRegular expression search is inavailable.%n%n%1
//
#define MSG_SEARCH_FAILEDTOLOADREGEXPENGINE 106L

//
// MessageId: MSG_SEARCH_REGEXPPATTERNSYNTAXERROR
//
// MessageText:
//
//  Specified pattern has syntax error.
//
#define MSG_SEARCH_REGEXPPATTERNSYNTAXERROR 107L

// debug ///////////////////////////////////////////////////////////////////
//
// MessageId: MSG_DEBUG_FAILEDTOGETPDM
//
// MessageText:
//
//  Failed to get Process Debug Manager. Can not continue debug.
//
#define MSG_DEBUG_FAILEDTOGETPDM         108L

//
// MessageId: MSG_DEBUG_INVALIDLANGUAGENAME
//
// MessageText:
//
//  No language bounded to current file's extension name, or language name is incorrect. Can not continue debug.
//
#define MSG_DEBUG_INVALIDLANGUAGENAME    109L

//
// MessageId: MSG_DEBUG_ENGINENOTSUPPORTDEBUGGING
//
// MessageText:
//
//  This script engine does not support debugging. Do you continue?
//
#define MSG_DEBUG_ENGINENOTSUPPORTDEBUGGING 110L

//
// MessageId: MSG_DEBUG_ENGINENOTSUPPORTPARSING
//
// MessageText:
//
//  This script engine does not provide parser. Can not continue debug.
//
#define MSG_DEBUG_ENGINENOTSUPPORTPARSING 111L

//
// MessageId: MSG_DEBUG_DOCUMENTISDEBUGGING
//
// MessageText:
//
//  %1%nThis document is debugging now. Do you stop debugging?
//
#define MSG_DEBUG_DOCUMENTISDEBUGGING    112L

// tool ////////////////////////////////////////////////////////////////////
//
// MessageId: MSG_TOOL_EXENOTREGISTERED
//
// MessageText:
//
//  "%1"%nThis document type is not registered program.
//
#define MSG_TOOL_EXENOTREGISTERED        113L

//
// MessageId: MSG_TOOL_FAILEDTORUNEXE
//
// MessageText:
//
//  Failed to run registered program.%nProgram path name may be incorrect.
//
#define MSG_TOOL_FAILEDTORUNEXE          114L

// menu ////////////////////////////////////////////////////////////////////
//
// MessageId: MSG_MENU_FILETOP
//
// MessageText:
//
//  &File
//
#define MSG_MENU_FILETOP                 115L

//
// MessageId: MSG_MENU_FILEMRU
//
// MessageText:
//
//  &Most Recent Used Files
//
#define MSG_MENU_FILEMRU                 116L

//
// MessageId: MSG_MENU_FILEOPE
//
// MessageText:
//
//  &File Operation
//
#define MSG_MENU_FILEOPE                 117L

//
// MessageId: MSG_MENU_EDITTOP
//
// MessageText:
//
//  &Edit
//
#define MSG_MENU_EDITTOP                 118L

//
// MessageId: MSG_MENU_EDITADVANCED
//
// MessageText:
//
//  Ad&vanced Operation
//
#define MSG_MENU_EDITADVANCED            119L

//
// MessageId: MSG_MENU_EDITINSUNICTRL
//
// MessageText:
//
//  &Insert Unicode Controls
//
#define MSG_MENU_EDITINSUNICTRL          120L

//
// MessageId: MSG_MENU_EDITINSUNIWS
//
// MessageText:
//
//  Insert Unicode &Whitespace
//
#define MSG_MENU_EDITINSUNIWS            121L

//
// MessageId: MSG_MENU_EDITPLUGINS
//
// MessageText:
//
//  Plu&gins
//
#define MSG_MENU_EDITPLUGINS             122L

//
// MessageId: MSG_MENU_EDITFAILEDTOLOAD
//
// MessageText:
//
//  (Failed to load)
//
#define MSG_MENU_EDITFAILEDTOLOAD        123L

//
// MessageId: MSG_MENU_SEARCHTOP
//
// MessageText:
//
//  &Search
//
#define MSG_MENU_SEARCHTOP               124L

//
// MessageId: MSG_MENU_VIEWTOP
//
// MessageText:
//
//  &View
//
#define MSG_MENU_VIEWTOP                 125L

//
// MessageId: MSG_MENU_DEBUGTOP
//
// MessageText:
//
//  &Debug
//
#define MSG_MENU_DEBUGTOP                126L

//
// MessageId: MSG_MENU_TOOLTOP
//
// MessageText:
//
//  &Tool
//
#define MSG_MENU_TOOLTOP                 127L

//
// MessageId: MSG_MENU_TOOLAPPLYDOCTYPE
//
// MessageText:
//
//  &Apply Document Type
//
#define MSG_MENU_TOOLAPPLYDOCTYPE        128L

//
// MessageId: MSG_MENU_HELPTOP
//
// MessageText:
//
//  &Help
//
#define MSG_MENU_HELPTOP                 129L
